.. _plugins:
.. _sqlalchemy.ext:

sqlalchemy.ext
==============

SQLAlchemy has a variety of extensions available which provide extra
functionality to SA, either via explicit usage or by augmenting the
core behavior.

.. toctree::
    :glob:

    declarative
    associationproxy
    orderinglist
    serializer
    sqlsoup
    compiler
    horizontal_shard

